==> rspec-parameterized-table_syntax-2.1.0.tar.gz: rspec-parameterized-table_syntax-2.1.0/CHANGELOG.md <==
## [Unreleased]
[full changelog](https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/compare/v2.1.0...main)

## [2.1.0](https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/releases/tag/v2.1.0) - 2025-12-28
[full changelog](https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/compare/v2.0.1...v2.1.0)

- Allow binding_of_caller to load under Ruby 4.0
  - https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/pull/22

## [2.0.1](https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/releases/tag/v2.0.1) - 2025-11-30
[full changelog](https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/compare/v2.0.0...v2.0.1)

- Release gem from GitHub Actions
  - https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/pull/14

## [2.0.0](https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/releases/tag/v2.0.0) - 2025-05-02
[full changelog](https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/compare/v1.0.1...v2.0.0)

- Requires rspec-parameterized-core v2
  - https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/pull/11

## [1.0.1] - 2023-09-26
[full changelog](https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/compare/v1.0.0...v1.0.1)

- Suppress unnecessary deprecation warning for Ruby v3.1.
  - https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/pull/7

## [1.0.0] - 2022-12-31
- https://github.com/tomykaira/rspec-parameterized/blob/master/CHANGELOG.md#v100-2022-12-31
- Drop support Ruby < 2.6 (explicitly)

==> rspec-parameterized-table_syntax-2.1.1.tar.gz: rspec-parameterized-table_syntax-2.1.1/CHANGELOG.md <==
## [Unreleased]
[full changelog](https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/compare/v2.1.1...main)

## [2.1.1](https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/releases/tag/v2.1.1) - 2026-02-15
[full changelog](https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/compare/v2.1.0...v2.1.1)

- Requires binding_of_caller v2+
  - https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/pull/24

## [2.1.0](https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/releases/tag/v2.1.0) - 2025-12-28
[full changelog](https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/compare/v2.0.1...v2.1.0)

- Allow binding_of_caller to load under Ruby 4.0
  - https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/pull/22

## [2.0.1](https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/releases/tag/v2.0.1) - 2025-11-30
[full changelog](https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/compare/v2.0.0...v2.0.1)

- Release gem from GitHub Actions
  - https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/pull/14

## [2.0.0](https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/releases/tag/v2.0.0) - 2025-05-02
[full changelog](https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/compare/v1.0.1...v2.0.0)

- Requires rspec-parameterized-core v2
  - https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/pull/11

## [1.0.1] - 2023-09-26
[full changelog](https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/compare/v1.0.0...v1.0.1)

- Suppress unnecessary deprecation warning for Ruby v3.1.
  - https://github.com/rspec-parameterized/rspec-parameterized-table_syntax/pull/7

## [1.0.0] - 2022-12-31
- https://github.com/tomykaira/rspec-parameterized/blob/master/CHANGELOG.md#v100-2022-12-31
- Drop support Ruby < 2.6 (explicitly)
